--******************************************************************************************************************************
--* Licensed Materials - Property of IBM                                                                                       *
--* (c) Copyright IBM Corp. 2008, 2009 All Rights Reserved.                                                                    *
--*                                                                                                                            *
--*US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp*
--******************************************************************************************************************************

SET CURRENT SCHEMA $RIBA_SCHEMA;

CREATE TABLE SCORECARD (
		SCORECARD_ID VARCHAR(40) NOT NULL,
		NAME VARCHAR(255) NOT NULL,
		DESC VARCHAR(2000) NOT NULL
	)
	IN VSTR_32K INDEX IN VSTR_IDX;

CREATE TABLE SCORECARD_METRICS  (
		  SCORECARD_ID VARCHAR(40) NOT NULL,
		  METRIC_TYPE_ID VARCHAR(40) NOT NULL
	)   
	IN VSTR_32K INDEX IN VSTR_IDX ; 

CREATE TABLE OBJECTIVE (
		OBJECTIVE_ID VARCHAR(40) NOT NULL,
		NAME VARCHAR(255) NOT NULL,
		DESC VARCHAR(2000) NOT NULL
	)
	IN VSTR_32K INDEX IN VSTR_IDX;

CREATE TABLE METRIC_TYPE (
		METRIC_TYPE_ID VARCHAR(40) NOT NULL,
		NAME VARCHAR(255) NOT NULL,
		DESC VARCHAR(2000) NOT NULL,
		OBJECTIVE_ID VARCHAR(40) NOT NULL,
		TARGET DECIMAL(18 , 2) DEFAULT 0.00,
		TOLERANCE INTEGER DEFAULT 10 NOT NULL,
		POSITIVE_TREND INTEGER,
		AGGREGATION_TYPE INTEGER,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT TIMESTAMP NOT NULL
	)
	IN VSTR_32K INDEX IN VSTR_IDX;

CREATE TABLE METRIC_TYPE_HIERARCHY  (
		PARENT_TYPE_ID VARCHAR(40) NOT NULL,
		CHILD_TYPE_ID VARCHAR(40) NOT NULL,
		WEIGHT INTEGER, 
		REC_DATETIME TIMESTAMP DEFAULT CURRENT TIMESTAMP NOT NULL 
	)   
	IN VSTR_32K INDEX IN VSTR_IDX ; 

CREATE TABLE TIME_PERIOD (
		PERIOD_ID INTEGER NOT NULL,
		NAME VARCHAR(255) NOT NULL,
		START_DATE DATE NOT NULL,
		END_DATE DATE NOT NULL,
		LEVEL_CODE CHAR(1) NOT NULL,
		LEVEL_NUMBER INTEGER NOT NULL,
		LEVEL_NAME VARCHAR(10) NOT NULL,
		PERIOD_NUMBER INTEGER NOT NULL,
		YEAR INTEGER,
		QUARTER INTEGER,
		MONTH INTEGER,
		WEEK INTEGER,
		LAST_PERIOD_ID INTEGER,
		PARENT_PERIOD_ID INTEGER,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT TIMESTAMP NOT NULL
	)
	IN VSTR_32K INDEX IN VSTR_IDX;

CREATE TABLE SCOPE (
		SCOPE_ID INTEGER NOT NULL,
		NAME VARCHAR(255) NOT NULL,
		TYPE VARCHAR(40) NOT NULL,
		REFERENCE_ID INTEGER,
		REC_DATETIME TIMESTAMP DEFAULT CURRENT TIMESTAMP NOT NULL
	)
	IN VSTR_32K INDEX IN VSTR_IDX;

CREATE TABLE METRIC_STAGING (
		METRIC_TYPE_ID VARCHAR(40) NOT NULL,
		SCOPE_ID INTEGER NOT NULL,
		PERIOD_ID INTEGER NOT NULL,
		ACTUAL DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		TARGET DECIMAL(18 , 2) DEFAULT 0.00
	)
	IN VSTR_32K INDEX IN VSTR_IDX;

CREATE TABLE PM_METRIC_CURRENT (
		PM_METRIC_ID INTEGER NOT NULL,
		METRIC_TYPE_ID VARCHAR(40) NOT NULL,
		SCOPE_ID INTEGER NOT NULL,
		PERIOD_ID INTEGER NOT NULL,
		ACTUAL DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		TARGET DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		UPPER_BOUND DECIMAL(18 , 2),
		LOWER_BOUND DECIMAL(18 , 2),
		STATUS_IND VARCHAR(10) NOT NULL,
		TREND_IND VARCHAR(10),
		REC_DATETIME TIMESTAMP DEFAULT CURRENT TIMESTAMP NOT NULL
	)
	IN VSTR_32K INDEX IN VSTR_IDX;

CREATE TABLE PM_METRIC (
		PM_METRIC_ID INTEGER NOT NULL,
		METRIC_TYPE_ID VARCHAR(40) NOT NULL,
		SCOPE_ID INTEGER NOT NULL,
		PERIOD_ID INTEGER NOT NULL,
		ACTUAL DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		TARGET DECIMAL(18 , 2) DEFAULT 0.00 NOT NULL,
		UPPER_BOUND DECIMAL(18 , 2),
		LOWER_BOUND DECIMAL(18 , 2),
		STATUS_IND VARCHAR(10) NOT NULL,
		TREND_IND VARCHAR(10),
		REC_DATETIME TIMESTAMP DEFAULT CURRENT TIMESTAMP NOT NULL
	)
	IN VSTR_32K INDEX IN VSTR_IDX;

CREATE TABLE PROJECT_HEALTH  (
		  ID INTEGER NOT NULL , 
		  TIME_TO_VALUE_OVERALL_ID VARCHAR(40) NOT NULL , 
		  TIME_TO_VALUE_OVERALL_SCORE DECIMAL(18,2) NOT NULL , 
		  TIME_TO_VALUE_OVERALL_STATUS VARCHAR(255) NOT NULL , 
		  TIME_TO_VALUE_OVERALL_TREND VARCHAR(255) NOT NULL , 
		  ON_TIME_DELIVERY_RISK_ID VARCHAR(40) NOT NULL , 
		  ON_TIME_DELIVERY_RISK_SCORE DECIMAL(18,2) NOT NULL , 
		  ON_TIME_DELIVERY_RISK_STATUS VARCHAR(255) NOT NULL , 
		  ON_TIME_DELIVERY_RISK_TREND VARCHAR(255) NOT NULL , 
		  SPI_ID VARCHAR(40) NOT NULL , 
		  SPI_SCORE DECIMAL(18,2) NOT NULL , 
		  SPI_STATUS VARCHAR(255) NOT NULL , 
		  SPI_TREND VARCHAR(255) NOT NULL , 
		  CPI_ID VARCHAR(40) NOT NULL , 
		  CPI_SCORE DECIMAL(18,2) NOT NULL , 
		  CPI_STATUS VARCHAR(255) NOT NULL , 
		  CPI_TREND VARCHAR(255) NOT NULL , 
		  DEFECT_DENSITY_ID VARCHAR(40) NOT NULL , 
		  DEFECT_DENSITY_SCORE DECIMAL(18,2) NOT NULL , 
		  DEFECT_DENSITY_STATUS VARCHAR(255) NOT NULL , 
		  DEFECT_DENSITY_TREND VARCHAR(255) NOT NULL , 
		  TEST_SUCCESS_RATE_ID VARCHAR(40) NOT NULL , 
		  TEST_SUCCESS_RATE_SCORE DECIMAL(18,2) NOT NULL , 
		  TEST_SUCCESS_RATE_STATUS VARCHAR(255) NOT NULL , 
		  TEST_SUCCESS_RATE_TREND VARCHAR(255) NOT NULL , 
		  QUALITY_OVERALL_ID VARCHAR(40) NOT NULL , 
		  QUALITY_OVERALL_SCORE DECIMAL(18,2) NOT NULL , 
		  QUALITY_OVERALL_STATUS VARCHAR(255) NOT NULL , 
		  QUALITY_OVERALL_TREND VARCHAR(255) NOT NULL , 
		  TEST_COVERAGE_ID VARCHAR(40) NOT NULL , 
		  TEST_COVERAGE_SCORE DECIMAL(18,2) NOT NULL , 
		  TEST_COVERAGE_STATUS VARCHAR(255) NOT NULL , 
		  TEST_COVERAGE_TREND VARCHAR(255) NOT NULL , 
		  ENHANCEMENT_BACKLOG_ID VARCHAR(40) NOT NULL , 
		  ENHANCEMENT_BACKLOG_SCORE DECIMAL(18,2) NOT NULL , 
		  ENHANCEMENT_BACKLOG_STATUS VARCHAR(255) NOT NULL , 
		  ENHANCEMENT_BACKLOG_TREND VARCHAR(255) NOT NULL , 
		  CM_SATISFACTION_OVERALL_ID VARCHAR(40) NOT NULL , 
		  CM_SATISFACTION_OVERALL_SCORE DECIMAL(18,2) NOT NULL , 
		  CM_SATISFACTION_OVERALL_STATUS VARCHAR(255) NOT NULL , 
		  CM_SATISFACTION_OVERALL_TREND VARCHAR(255) NOT NULL , 
		  SLA_MET_ID VARCHAR(40) NOT NULL , 
		  SLA_MET_SCORE DECIMAL(18,2) NOT NULL , 
		  SLA_MET_STATUS VARCHAR(255) NOT NULL , 
		  SLA_MET_TREND VARCHAR(255) NOT NULL , 
		  TIME_TO_RESOLUTION_ID VARCHAR(40) NOT NULL , 
		  TIME_TO_RESOLUTION_SCORE DECIMAL(18,2) NOT NULL , 
		  TIME_TO_RESOLUTION_STATUS VARCHAR(255) NOT NULL , 
		  TIME_TO_RESOLUTION_TREND VARCHAR(255) NOT NULL , 
		  SCOPE_REFERENCE_ID VARCHAR(40) NOT NULL , 
		  SCOPE_NAME VARCHAR(255) NOT NULL , 
		  PRJ_OVERALL_HEALTH_ID INTEGER,
		  PRJ_OVERALL_HEALTH_SCORE DECIMAL(18,2),
		  PRJ_OVERALL_HEALTH_STATUS VARCHAR(255),
		  PRJ_OVERALL_HEALTH_TREND VARCHAR(255),
		  REC_DATETIME TIMESTAMP NOT NULL DEFAULT CURRENT TIMESTAMP )   
		 IN VSTR_32K INDEX IN VSTR_IDX ; 

-- PRIMARY KEY CONSTRAINTS

ALTER TABLE SCORECARD ADD CONSTRAINT SCORECARD_PK PRIMARY KEY	(SCORECARD_ID);

ALTER TABLE SCORECARD_METRICS ADD CONSTRAINT SCORECARD_MET_PK PRIMARY KEY	(SCORECARD_ID, METRIC_TYPE_ID);

ALTER TABLE TIME_PERIOD ADD CONSTRAINT TIME_PERIOD_PK PRIMARY KEY	(PERIOD_ID);

ALTER TABLE METRIC_TYPE ADD CONSTRAINT METRIC_TYPE_PK PRIMARY KEY	(METRIC_TYPE_ID);

ALTER TABLE METRIC_TYPE_HIERARCHY ADD CONSTRAINT METRIC_TYPHIERA_PK PRIMARY KEY (PARENT_TYPE_ID, CHILD_TYPE_ID);

ALTER TABLE OBJECTIVE ADD CONSTRAINT OBJECTIVE_PK PRIMARY KEY	(OBJECTIVE_ID);

ALTER TABLE SCOPE ADD CONSTRAINT SCOPE_PK PRIMARY KEY	(SCOPE_ID);

ALTER TABLE PM_METRIC_CURRENT ADD CONSTRAINT PM_METRIC_CURR_PK PRIMARY KEY	(PM_METRIC_ID);

ALTER TABLE METRIC_STAGING ADD CONSTRAINT METRIC_STAGING_PK PRIMARY KEY	(METRIC_TYPE_ID, SCOPE_ID, PERIOD_ID);

ALTER TABLE PM_METRIC ADD CONSTRAINT PM_METRIC_PK PRIMARY KEY	(PM_METRIC_ID);


-- FOREIGN KEY CONSTRAINTS


ALTER TABLE SCORECARD_METRICS ADD CONSTRAINT SCORECARD_MET_FK1 FOREIGN KEY (SCORECARD_ID) 
	REFERENCES SCORECARD (SCORECARD_ID);

ALTER TABLE SCORECARD_METRICS ADD CONSTRAINT SCORECARD_MET_FK2 FOREIGN KEY (METRIC_TYPE_ID) 
	REFERENCES METRIC_TYPE (METRIC_TYPE_ID);

ALTER TABLE METRIC_TYPE_HIERARCHY ADD CONSTRAINT METRIC_TYP_MET_FK1 FOREIGN KEY (PARENT_TYPE_ID) 
	REFERENCES METRIC_TYPE (METRIC_TYPE_ID);

ALTER TABLE METRIC_TYPE_HIERARCHY ADD CONSTRAINT METRIC_TYP_MET_FK2 FOREIGN KEY (CHILD_TYPE_ID) 
	REFERENCES METRIC_TYPE (METRIC_TYPE_ID);

ALTER TABLE PM_METRIC_CURRENT ADD CONSTRAINT PM_METRIC_METR_FK FOREIGN KEY	(METRIC_TYPE_ID)
	REFERENCES METRIC_TYPE	(METRIC_TYPE_ID);

ALTER TABLE METRIC_TYPE ADD CONSTRAINT METRIC_TYPE_FK FOREIGN KEY	(OBJECTIVE_ID)
	REFERENCES OBJECTIVE	(OBJECTIVE_ID);

ALTER TABLE PM_METRIC_CURRENT ADD CONSTRAINT PM_METRIC_SCOP_FK FOREIGN KEY	(SCOPE_ID)
	REFERENCES SCOPE	(SCOPE_ID);

ALTER TABLE PM_METRIC_CURRENT ADD CONSTRAINT PM_METRIC_TIME_FK FOREIGN KEY	(PERIOD_ID)
	REFERENCES TIME_PERIOD	(PERIOD_ID);

ALTER TABLE METRIC_STAGING ADD CONSTRAINT METRIC_S_METRI_FK FOREIGN KEY	(METRIC_TYPE_ID)
	REFERENCES METRIC_TYPE	(METRIC_TYPE_ID);

ALTER TABLE METRIC_STAGING ADD CONSTRAINT METRIC_STA_SCOP_FK FOREIGN KEY	(SCOPE_ID)
	REFERENCES SCOPE	(SCOPE_ID);

ALTER TABLE METRIC_STAGING ADD CONSTRAINT METRIC_S_TIME__FK FOREIGN KEY	(PERIOD_ID)
	REFERENCES TIME_PERIOD	(PERIOD_ID);

ALTER TABLE PM_METRIC ADD CONSTRAINT PM_MTYPE_FK FOREIGN KEY	(METRIC_TYPE_ID)
	REFERENCES METRIC_TYPE	(METRIC_TYPE_ID);

ALTER TABLE PM_METRIC ADD CONSTRAINT PM_METRIC_SCOPE_FK FOREIGN KEY	(SCOPE_ID)
	REFERENCES SCOPE	(SCOPE_ID);

ALTER TABLE PM_METRIC ADD CONSTRAINT PM_MET_TIME_PER_FK FOREIGN KEY	(PERIOD_ID)
	REFERENCES TIME_PERIOD	(PERIOD_ID);

COMMIT;
